==> nextcloud-27.1.4.tgz: nextcloud/apps/user_status/l10n/ro.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Statusuri recente",
    "No recent status changes" : "Nu există modificări recente ale statutului",
    "In a meeting" : "În cadrul unei întâlniri",
    "Commuting" : "În deplasare",
    "Out sick" : "Bolnav",
    "Vacationing" : "În vacanță",
    "Working remotely" : "Lucru la distanță",
    "In a call" : "Într-un apel",
    "User status" : "Statusul utilizatorului",
    "What is your status?" : "Care este statusul dumneavoastră?",
    "Set status" : "Setează status",
    "Online status" : "Status online",
    "Status message" : "Mesaj de status",
    "Clear status message" : "Șterge mesajul de stare",
    "Set status message" : "Setează mesajul de status",
    "There was an error saving the status" : "S-a produs o eroare la salvarea stării",
    "There was an error clearing the status" : "S-a produs o eroare de ștergere a statutului",
    "Don't clear" : "Nu curăța",
    "Today" : "Azi",
    "This week" : "Săptămâna asta",
    "Online" : "Online",
    "Away" : "Plecat",
    "Do not disturb" : "Nu deranja",
    "Invisible" : "Invizibil",
    "Offline" : "Offline",
    "There was an error saving the new status" : "S-a produs o eroare de salvare a noului status",
    "30 minutes" : "30 minute",
    "1 hour" : "1 oră",
    "4 hours" : "4 ore",
    "Mute all notifications" : "Dezactivați toate notificările",
    "Appear offline" : "Apari deconectat",
    "View profile" : "Vezi profilul",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-27.1.5.tgz: nextcloud/apps/user_status/l10n/ro.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Statusuri recente",
    "No recent status changes" : "Nu există modificări recente ale statutului",
    "In a meeting" : "În cadrul unei întâlniri",
    "Commuting" : "În deplasare",
    "Out sick" : "Bolnav",
    "Vacationing" : "În vacanță",
    "Working remotely" : "Lucru la distanță",
    "In a call" : "Într-un apel",
    "User status" : "Statusul utilizatorului",
    "Clear status after" : "Șterge statusul după",
    "Emoji for your status message" : "Emoji pentru mesajul de status",
    "What is your status?" : "Care este statusul dumneavoastră?",
    "Predefined statuses" : "Stări predefinite",
    "Previously set" : "Setat anterior",
    "Reset status" : "Resetează starea",
    "Set status" : "Setează status",
    "Online status" : "Status online",
    "Status message" : "Mesaj de status",
    "Your status was set automatically" : "Statusul a fost setat automat",
    "Clear status message" : "Șterge mesajul de stare",
    "Set status message" : "Setează mesajul de status",
    "Reset status to \"{icon} {message}\"" : "Resetează statusul la \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Resetează statusul la \"{message}\"",
    "Reset status to \"{icon}\"" : "Resetează statusul la \"{icon}\"",
    "There was an error saving the status" : "S-a produs o eroare la salvarea stării",
    "There was an error clearing the status" : "S-a produs o eroare de ștergere a statutului",
    "There was an error reverting the status" : "Eroare la revenirea la statusul anterior",
    "Don't clear" : "Nu curăța",
    "Today" : "Azi",
    "This week" : "Săptămâna asta",
    "Online" : "Online",
    "Away" : "Plecat",
    "Do not disturb" : "Nu deranja",
    "Invisible" : "Invizibil",
    "Offline" : "Offline",
    "There was an error saving the new status" : "S-a produs o eroare de salvare a noului status",
    "30 minutes" : "30 minute",
    "1 hour" : "1 oră",
    "4 hours" : "4 ore",
    "Mute all notifications" : "Dezactivați toate notificările",
    "Appear offline" : "Apari deconectat",
    "View profile" : "Vezi profilul",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
